AATKitAdNetworkOptions class

Allows to pass network-specific configurations to AATKit.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AATKitAdNetworkOptions({AppNexusOptions? appNexusOptions, AdMobOptions? adMobOptions, DFPOptions? dfpOptions, MetaBiddingOptions? metaBiddingOptions, GraviteRTBOptions? graviteRTBOptions, DisplayIOOptions? displayIOOptions})
Constructor for AATKitAdNetworkOptions
AATKitAdNetworkOptions.fromJson(Map<String, dynamic> json)
factory

Properties

adMobOptions ↔ AdMobOptions?
AdMob specific options.
getter/setter pair
appNexusOptions ↔ AppNexusOptions?
AppNexus specific options.
getter/setter pair
dfpOptions ↔ DFPOptions?
DFP specific options.
getter/setter pair
displayIOOptions ↔ DisplayIOOptions?
Display.io specific configurations
getter/setter pair
graviteRTBOptions ↔ GraviteRTBOptions?
GraviteRTB specific options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metaBiddingOptions ↔ MetaBiddingOptions?
Meta Bidding specific options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited