DisplayIOOptions class

Display.io specific configurations

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

DisplayIOOptions({int? interscrollerHeight, int? interscrollerTopOffset, bool? showSoundControl})
DisplayIOOptions.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
interscrollerHeight ↔ int?
Set different height to interscroller
getter/setter pair
interscrollerTopOffset ↔ int?
Set different top offset to interscroller
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showSoundControl ↔ bool?
Set if sound control should be visible. Note: Available only on iOS.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited