CmpAppConsent class

Wrapper for SFBX/AppConsent CMP

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CmpAppConsent({String? appKey, bool? forceGDPR, bool fullscreen = false})
CmpAppConsent.fromJson(Map<String, dynamic> json)
factory

Properties

appKey ↔ String?
AppConsent app key
getter/setter pair
forceGDPR ↔ bool?
Boolean to indicate if you want to force GDPR. Works only on iOS
getter/setter pair
fullscreen ↔ bool
Display introduction page in fullscreen if set to true, defaults to false. Works only on iOS
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited