ManagedConsent class

Will present a dialog for the users to grant or withhold their consent.

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ManagedConsent({CMP? cmp, ManagedConsentListener? listener})
ManagedConsent.fromJson(Map<String, dynamic> json)
factory

Properties

cmp ↔ CMP?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listener ↔ ManagedConsentListener?
getter/setter pair
noConsentNetworkStopSet ↔ Set<AdNetwork>?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited