SimpleConsent class

Allows to set the status of Non-IAB consent. Will also read the IAB consent string from SharedPreferences if available.

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SimpleConsent(NonIABConsent nonIABConsent)
SimpleConsent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
noConsentNetworkStopSet ↔ Set<AdNetwork>?
getter/setter pairinherited
nonIABConsent ↔ NonIABConsent
Status of Non-IAB consent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited