AATKitImpression class

Object containing impression level information.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AATKitImpression({String? bannerSize, required AdNetwork adNetwork, required String networkKey, required bool isDirectDeal, PriceInfo? priceInfo})
AATKitImpression.fromJson(Map<String, dynamic> json)
factory

Properties

adNetwork → AdNetwork
final
bannerSize → String?
The banner size as string (matching the ad key configuration), or null for non-banner ads
final
hashCode → int
The hash code for this object.
no setterinherited
isDirectDeal → bool
final
networkKey → String
The network name as string, matching the ad key configuration.
final
priceInfo → PriceInfo?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited