AppOpenAdPlacement class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
impressionListener ↔ ImpressionListener?
The impression listener for placement.
getter/setter pair
listener ↔ AppOpenPlacementListener?
Listener instance receiving AppOpenAd placement events
getter/setter pair
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statisticsListener ↔ StatisticsListener?
The statistics listener that will be notified about placement reporting events, like counted adspace, request etc.
getter/setter pair
targetingInfo ↔ Map<String, List<String>>
Targeting information for the given placement. Information provided for placement overrides targeting information for application set by the setTargetingInfo.
getter/setter pair

Methods

hasAd() → Future<bool>
Returns 'true' if there is an ad loaded for this placementId.
isFrequencyCapReached() → Future<bool>
Checks if desired impression cap (set on AddApptr Dashboard) is reached for this placement. Returns 'true' if impression cap is reached for given placement, 'false' otherwise.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload({bool? forceLoad}) → Future<bool>
Requests placement reload. Works only if automatic reloading is disabled. forceLoad: True if you want to clear the previously loaded ad before loading a new one.
setContentTargetingUrl(String url) → Future<void>
Sets the content targeting url for the application. This information will be used only if no placement-specific targeting is available.
setTargetingInfo(Map<String, List<String>> info) → Future<void>
Sets the targeting information for the given placement. Information provided for placement overrides targeting information for application set by the setTargetingInfo.
show() → Future<bool>
Shows the ad if ad is ready.
startAutoReload() → Future<void>
Enables automatic reloading of placement. When using this method, the placement will automatically reload once the current loaded ad has been shown.
stopAutoReload() → Future<void>
Stop the automatic reloading of the placement.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required String name}) → Future<AppOpenAdPlacement>
Factory method creating placement.